Crate oiseau

Crate oiseau 

Re-exports

pub extern crate rusqlite;
pub extern crate tokio_postgres;

Modules

cache
config
postgres
prelude
sqlite

Macros

pg_execute
pg_get
pg_params
pg_query_row
pg_query_rows
rparams
A macro making it more convenient to pass longer lists of parameters as a &[&dyn ToSql].
sqlite_execute
sqlite_get
sqlite_params
sqlite_query_row
sqlite_query_rows

Structs

PostgresRow
A row of data returned from the database by a query.
SqliteRow
A single result row of a query.