Re-exports
pub extern crate rusqlite;pub extern crate tokio_postgres;
Modules
Macros
- pg_
execute - pg_get
- pg_
params - pg_
query_ row - pg_
query_ rows - rparams
- A macro making it more convenient to pass longer lists of
parameters as a
&[&dyn ToSql]. - sqlite_
execute - sqlite_
get - sqlite_
params - sqlite_
query_ row - sqlite_
query_ rows
Structs
- Postgres
Row - A row of data returned from the database by a query.
- Sqlite
Row - A single result row of a query.